==> jts_1.17.0+ds.orig.tar.xz: jts-1.17.0/modules/app/src/main/java/org/locationtech/jtstest/cmd/CommandOptions.java <==
/*
 * Copyright (c) 2019 Martin Davis.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * and Eclipse Distribution License v. 1.0 which accompanies this distribution.
 * The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v20.html
 * and the Eclipse Distribution License is available at
 *
 * http://www.eclipse.org/org/documents/edl-v10.php.
 */
package org.locationtech.jtstest.cmd;

public class CommandOptions {
  public static final String GEOMFUNC = "geomfunc";
  public static final String VERBOSE = "verbose";
  
  public static final String OP = "op";
  public static final String GEOMA = "a";
  public static final String GEOMB = "b";
  public static final String GEOMAB = "ab";
  public static final String FORMAT = "f";
  public static final String HELP = "help";
  public static final String V = "v";
  public static final String REPEAT = "repeat";
  public static final String EACH = "each";
  public static final String ARGS = "args";
  public static final String STDIN = "stdin";
  public static final String FORMAT_GML = "gml";
  public static final String FORMAT_WKB = "wkb";
  public static final String FORMAT_TXT = "txt";
  public static final String FORMAT_WKT = "wkt";
  public static final String FORMAT_GEOJSON = "geojson";
  public static final String FORMAT_SVG = "svg";
  public static final String VALIDATE = "validate";
  public static final String INDEX = "index";

}

==> jts_1.19.0+ds.orig.tar.xz: jts-1.19.0/modules/app/src/main/java/org/locationtech/jtstest/cmd/CommandOptions.java <==
/*
 * Copyright (c) 2019 Martin Davis.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * and Eclipse Distribution License v. 1.0 which accompanies this distribution.
 * The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v20.html
 * and the Eclipse Distribution License is available at
 *
 * http://www.eclipse.org/org/documents/edl-v10.php.
 */
package org.locationtech.jtstest.cmd;

public class CommandOptions {
  public static final String GEOMFUNC = "geomfunc";
  public static final String VERBOSE = "verbose";
  
  public static final String OP = "op";
  public static final String EXPLODE = "explode";
  public static final String FORMAT = "f";
  public static final String GEOMA = "a";
  public static final String GEOMB = "b";
  public static final String GEOMAB = "ab";
  public static final String COLLECT = "collect";
  public static final String HELP = "help";
  public static final String V = "v";
  public static final String REPEAT = "repeat";
  public static final String SRID = "srid";
  //public static final String EACH = "each";
  public static final String EACHA = "eacha";
  public static final String EACHB = "eachb";
  public static final String ARGS = "args";
  public static final String VALIDATE = "validate";
  public static final String INDEX = "index";
  
  public static final String STDIN = "stdin";
  public static final String FORMAT_GML = "gml";
  public static final String FORMAT_WKB = "wkb";
  public static final String FORMAT_TXT = "txt";
  public static final String FORMAT_WKT = "wkt";
  public static final String FORMAT_GEOJSON = "geojson";
  public static final String FORMAT_SVG = "svg";
  public static final String TIME = "time";
  public static final String LIMIT = "limit";
  public static final String OFFSET = "offset";
  public static final String WHERE = "where";

}
